pub struct Method {
pub fn_ptr: usize,
pub input_layout: Struct,
pub output_layout: Layout,
}Expand description
A description on the method signature, to guide jyafn to generate the correct method call on this resource.
Fields
fn_ptr: usizeThe function pointer to be used in the jyafn code.
input_layout: StructThe layout of the input parameters.
output_layout: LayoutThe layout of the output parameters.